/*
 
 Les 7 VO Arduino Lessenserie Fontys Hogeschool ICT
   THEORIE: Functies
   
   Maak een kleurenfestijn met een RGB LED
   
 Benodigde onderdelen:
 1 x RGB LED
 3 x 220 ohm weerstand
 
Hardware connecties:

Een RGB LED is eigenlijk drie LED's in een: Rood, Groen en Blauw.
Door deze te mixen kun je allerlei kleuren maken.

De vier poten zijn: Rood, Common, Groen, Blauw.

Verbind Rood met een 220 ohm weerstand. Verbind de andere kant
van de weerstand met Arduino Digitale PIN 9.

Verbind COMMON pin met GND.

Verbind groen met een 220 ohm weerstand. Verbind de andere kant
van de weerstand met Arduino Digitale PIN 10.

Verbind Blauw met een 220 ohm weerstand. Verbind de andere kant
van de weerstand met Arduino Digitale PIN 11.

*/

// const is een variable die nooit veranderd.
const int RED_PIN = 9;
const int GREEN_PIN = 10;
const int BLUE_PIN = 11;

// in variabele DISPLAY_TIME leggen we de snelheid vast.
// door deze te veranderen kun je de 'fading" versnellen of vertragen.
int DISPLAY_TIME = 100;  // In milliseconds

void setup()
{
  // Configureer de Arduino PINS die gebruikt worden als OUTPUT
  pinMode(RED_PIN, OUTPUT);
  pinMode(GREEN_PIN, OUTPUT);
  pinMode(BLUE_PIN, OUTPUT);
}

// de loop roept twee functies aan.
void loop()
{
  // deze functies toont de primaire, secundaire kleuren en zwart (uit) en wit.
  mainColors();
  // deze functie loopt staploos door de hele kleurencirkel
  showSpectrum();
}

// deze functies toont de primaire en secundaire kleuren
void mainColors()
{
  // Uit (alle LEDs uit):
  digitalWrite(RED_PIN, LOW);
  digitalWrite(GREEN_PIN, LOW);
  digitalWrite(BLUE_PIN, LOW);
  delay(1000);
  
  // Rood:
  digitalWrite(RED_PIN, HIGH);
  digitalWrite(GREEN_PIN, LOW);
  digitalWrite(BLUE_PIN, LOW);
  delay(1000);
  
  // Groen:
  digitalWrite(RED_PIN, LOW);
  digitalWrite(GREEN_PIN, HIGH);
  digitalWrite(BLUE_PIN, LOW);
  delay(1000);
  
  // Blauw:
  digitalWrite(RED_PIN, LOW);
  digitalWrite(GREEN_PIN, LOW);
  digitalWrite(BLUE_PIN, HIGH);
  delay(1000);
  
  //Geel (rood en groen aan):
  digitalWrite(RED_PIN, HIGH);
  digitalWrite(GREEN_PIN, HIGH);
  digitalWrite(BLUE_PIN, LOW);
  delay(1000);
  
  // Cyaan (groen en blauw aan):
  digitalWrite(RED_PIN, LOW);
  digitalWrite(GREEN_PIN, HIGH);
  digitalWrite(BLUE_PIN, HIGH);
  
  delay(1000);
  
  // Paars (rood en blauw aan):
  digitalWrite(RED_PIN, HIGH);
  digitalWrite(GREEN_PIN, LOW);
  digitalWrite(BLUE_PIN, HIGH);
  delay(1000);
  
  // Wit (alle LEDs aan):
  digitalWrite(RED_PIN, HIGH);
  digitalWrite(GREEN_PIN, HIGH);
  digitalWrite(BLUE_PIN, HIGH);
  delay(1000);
}

// deze functie loopt staploos door de hele kleurencirkel
// Daarvoor gebruiken we een for() loop
void showSpectrum()
{
  int x;
  for (x = 0; x < 768; x++)
  {
    showRGB(x);  // roep functie RGBspectrum() aan met nieuwe x-waarde
    delay(10);
  }
}





// Functie showRGB() vertaalt de nummers van 0 tot 767 naar een kleur
// Als je de hele range gebruikt loopt de LED staploos door het hele kleurenspectrum 
// de basis nummers zijn:
// 0   = puur rood
// 255 = puur groen
// 511 = puur blauw
// 767 = puur rood (weer)
// tussenliggende nummers zijn gemixte kleuren
void showRGB(int color)
{
  int redIntensity;
  int greenIntensity;
  int blueIntensity;
  // We gebruiken if/else om te bepalen of x in de R,G, of B zone zit.
  // Een zone omvat 0-255 (want analogWrite() wil een nummer tussen 0 en 255)
  // In elke zone berekenen we de Helderheid van R, G en B.
 
  if (color <= 255)          // zone 1
  {
    redIntensity = 255 - color;    // Rood verloopt van Aan naar Uit
    greenIntensity = color;        // Groen verloopt van Uit naar Aan
    blueIntensity = 0;             // Blauw is Uit
  }
  else if (color <= 511)     // zone 2
  {
    redIntensity = 0;                     // Rood is Uit
    greenIntensity = 255 - (color - 256); // Groen van Aan naar Uit
    blueIntensity = (color - 256);        // Blauw van Uit naar Aan
  }
  else // color >= 512       // zone 3
  {
    redIntensity = (color - 512);         // Rood van Uit naar Aan
    greenIntensity = 0;                   // Groen is Uit
    blueIntensity = 255 - (color - 512);  // Blauw van Aan naar Uit
  }
  // En nu deze waardes naar de LED sturen
  analogWrite(RED_PIN, redIntensity);
  analogWrite(BLUE_PIN, blueIntensity);
  analogWrite(GREEN_PIN, greenIntensity);
}

